import { KernelMessage } from "@jupyterlab/services";
import * as base from "@jupyter-widgets/base";
import { DOMWidgetView, WidgetModel } from "@jupyter-widgets/base";
import { WidgetComm } from "./widget-comms";
import { RecordOf } from "immutable";
import { KernelNotStartedProps, LocalKernelProps, RemoteKernelProps } from "@nteract/core";
/**
 * The WidgetManager extends the ManagerBase class and is required
 * by the ipywidgets implementation for rendering all models. This
 * WidgetManager contains some overrides to get it to play nice
 * with our RxJS-based kernel communication.
 */
export declare class WidgetManager extends base.ManagerBase<DOMWidgetView> {
    stateModelById: (id: string) => any;
    kernel: RecordOf<KernelNotStartedProps> | RecordOf<LocalKernelProps> | RecordOf<RemoteKernelProps> | null;
    constructor(kernel: any, stateModelById: (id: string) => any);
    update(kernel: any, stateModelById: (id: string) => any): void;
    /**
     * Load a class and return a promise to the loaded object.
     */
    loadClass(className: string, moduleName: string, moduleVersion: string): any;
    /**
     * Get a promise for a model by model id.
     *
     * #### Notes
     * If a model is not found, this will lookup the model in nteracts
     * redux store using the model_comm_lookup funciton and create it
     */
    get_model(model_id: string): Promise<WidgetModel> | undefined;
    /**
     * Shortcut to new_widget (creates the modelInfo from the state)
     * @param state
     * @param model_id
     */
    new_widget_from_state_and_id(state: any, model_id: string): Promise<base.WidgetModel>;
    /**
     * Create a comm and new widget model.
     * @param  options - same options as new_model but comm is not
     *                          required and additional options are available.
     * @param  serialized_state - serialized model attributes.
     */
    new_widget(options: any, serialized_state?: any): Promise<WidgetModel>;
    display_view(msg: KernelMessage.IMessage, view: base.DOMWidgetView, options: any): Promise<base.DOMWidgetView>;
    _get_comm_info(): Promise<{}>;
    /**
     * Create a comm which can be used for communication for a widget.
     *
     * If the data/metadata is passed in, open the comm before returning (i.e.,
     * send the comm_open message). If the data and metadata is undefined, we
     * want to reconstruct a comm that already exists in the kernel, so do not
     * open the comm by sending the comm_open message.
     *
     * @param comm_target_name Comm target name
     * @param model_id The comm id
     * @param data The initial data for the comm
     * @param metadata The metadata in the open message
     */
    _create_comm(comm_target_name: string, model_id: string, data?: any, metadata?: any, buffers?: ArrayBuffer[] | ArrayBufferView[]): Promise<WidgetComm>;
    /**
     * This method creates a view for a given model. It starts off
     * by registering a new model from the serialized model data. It
     * then uses the loadClass method to resolve a reference to the
     * WidgetView. Finally, it returns a reference to that Widget.
     * Note that we don't display the view here. Instead, we invoke
     * the `render` method on the WidgetView from within the
     * `BackboneWrapper` component and pass a reference to a React
     * element in this method.
     *
     * @param model   The Backbone-model associated with the widget
     * @param options Configuration options for rendering the widget
     */
    create_view(model: any, options: any): Promise<DOMWidgetView>;
}
