"use strict";
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (Object.hasOwnProperty.call(mod, k)) result[k] = mod[k];
    result["default"] = mod;
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
const base = __importStar(require("@jupyter-widgets/base"));
const controls = __importStar(require("@jupyter-widgets/controls"));
const widget_comms_1 = require("./widget-comms");
/**
 * The WidgetManager extends the ManagerBase class and is required
 * by the ipywidgets implementation for rendering all models. This
 * WidgetManager contains some overrides to get it to play nice
 * with our RxJS-based kernel communication.
 */
class WidgetManager extends base.ManagerBase {
    constructor(kernel, stateModelById) {
        super();
        this.kernel = kernel;
        this.stateModelById = stateModelById;
    }
    update(kernel, stateModelById) {
        this.kernel = kernel;
        this.stateModelById = stateModelById;
    }
    /**
     * Load a class and return a promise to the loaded object.
     */
    loadClass(className, moduleName, moduleVersion) {
        return new Promise(function (resolve, reject) {
            if (moduleName === "@jupyter-widgets/controls") {
                resolve(controls);
            }
            else if (moduleName === "@jupyter-widgets/base") {
                resolve(base);
            }
            else {
                return Promise.reject(`Module ${moduleName}@${moduleVersion} not found`);
            }
        }).then(function (module) {
            if (module[className]) {
                return module[className];
            }
            else {
                return Promise.reject(`Class ${className} not found in module ${moduleName}@${moduleVersion}`);
            }
        });
    }
    /**
     * Get a promise for a model by model id.
     *
     * #### Notes
     * If a model is not found, this will lookup the model in nteracts
     * redux store using the model_comm_lookup funciton and create it
     */
    get_model(model_id) {
        let model = super.get_model(model_id);
        if (model === undefined) {
            let model_state = this.stateModelById(model_id)
                .get("state")
                .toJS();
            model = this.new_widget_from_state_and_id(model_state, model_id);
        }
        return model;
    }
    /**
     * Shortcut to new_widget (creates the modelInfo from the state)
     * @param state
     * @param model_id
     */
    async new_widget_from_state_and_id(state, model_id) {
        let modelInfo = {
            model_id: model_id,
            model_name: state._model_name,
            model_module: state._model_module,
            model_module_version: state._module_version,
            view_name: state._view_name,
            view_module: state._view_module,
            view_module_version: state._view_module_version
        };
        return this.new_widget(modelInfo, state);
    }
    /**
     * Create a comm and new widget model.
     * @param  options - same options as new_model but comm is not
     *                          required and additional options are available.
     * @param  serialized_state - serialized model attributes.
     */
    new_widget(options, serialized_state = {}) {
        //first we check if the model was already created
        let widget = super.get_model(options.model_id); //we need to use the super because we override get_model to create what it can't find
        if (!widget) {
            widget = super.new_widget(options, serialized_state);
        }
        return widget;
    }
    display_view(msg, view, options) {
        return Promise.resolve(view);
    }
    _get_comm_info() {
        return Promise.resolve({});
    }
    /**
     * Create a comm which can be used for communication for a widget.
     *
     * If the data/metadata is passed in, open the comm before returning (i.e.,
     * send the comm_open message). If the data and metadata is undefined, we
     * want to reconstruct a comm that already exists in the kernel, so do not
     * open the comm by sending the comm_open message.
     *
     * @param comm_target_name Comm target name
     * @param model_id The comm id
     * @param data The initial data for the comm
     * @param metadata The metadata in the open message
     */
    _create_comm(comm_target_name, model_id, data, metadata, buffers) {
        //TODO: Check if we need to open a comm
        //TODO: Find a way to supply correct target module (only used in comm opens)
        if (this.kernel) {
            return Promise.resolve(new widget_comms_1.WidgetComm(model_id, this.comm_target_name, "<target module>", this.kernel));
        }
        else {
            return Promise.reject("Kernel is null or undefined");
        }
    }
    /**
     * This method creates a view for a given model. It starts off
     * by registering a new model from the serialized model data. It
     * then uses the loadClass method to resolve a reference to the
     * WidgetView. Finally, it returns a reference to that Widget.
     * Note that we don't display the view here. Instead, we invoke
     * the `render` method on the WidgetView from within the
     * `BackboneWrapper` component and pass a reference to a React
     * element in this method.
     *
     * @param model   The Backbone-model associated with the widget
     * @param options Configuration options for rendering the widget
     */
    async create_view(model, options) {
        const managerModel = await this.new_widget({
            model_id: options.model_id,
            model_name: model._model_name,
            model_module: model._model_module,
            model_module_version: model._module_version,
            view_name: model._view_name,
            view_module: model._view_module,
            view_module_version: model._view_module_version
        }, model);
        const WidgetView = await this.loadClass(managerModel.get("_view_name"), managerModel.get("_view_module"), managerModel.get("_view_module_version"));
        const widget = new WidgetView({
            model: managerModel,
            el: options.el
        });
        return widget;
    }
}
exports.WidgetManager = WidgetManager;
